# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_recoveryservices_backup.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3azure/azure_microsoft_recoveryservices_backup.proto\x12\x33oak9.tython.azure.microsoft_recoveryservices_backup\x1a\x13shared/shared.proto\"\x9e\x08\n!Microsoft_RecoveryServices_Backup\x12\x64\n\x13vaults_backupconfig\x18\x01 \x03(\x0b\x32G.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupconfig\x12|\n vaults_backup_encryption_configs\x18\x02 \x03(\x0b\x32R.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupEncryptionConfigs\x12\x96\x01\n.vaults_backup_fabrics_backup_protection_intent\x18\x03 \x03(\x0b\x32^.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupFabricsBackupProtectionIntent\x12\x91\x01\n+vaults_backup_fabrics_protection_containers\x18\x04 \x03(\x0b\x32\\.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupFabricsProtectionContainers\x12i\n\x16vaults_backup_policies\x18\x05 \x03(\x0b\x32I.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupPolicies\x12\x83\x01\n$vaults_backup_resource_guard_proxies\x18\x06 \x03(\x0b\x32U.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupResourceGuardProxies\x12r\n\x1avaults_backupstorageconfig\x18\x07 \x03(\x0b\x32N.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupstorageconfig\x12\x82\x01\n#vaults_private_endpoint_connections\x18\x08 \x03(\x0b\x32U.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsPrivateEndpointConnections\"\xaa\x04\n VaultsPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65_tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12^\n\x10private_endpoint\x18\x05 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_recoveryservices_backup.PrivateEndpoint\x12\x85\x01\n%private_link_service_connection_state\x18\x06 \x01(\x0b\x32V.oak9.tython.azure.microsoft_recoveryservices_backup.PrivateLinkServiceConnectionState\x12\x1a\n\x12provisioning_state\x18\x07 \x01(\t\x12m\n\x04tags\x18\x08 \x03(\x0b\x32_.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsPrivateEndpointConnections.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"a\n!PrivateLinkServiceConnectionState\x12\x17\n\x0f\x61\x63tion_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1d\n\x0fPrivateEndpoint\x12\n\n\x02id\x18\x01 \x01(\t\"\xb3\x03\n\x19VaultsBackupstorageconfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65_tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12!\n\x19\x63ross_region_restore_flag\x18\x05 \x01(\x08\x12\x13\n\x0b\x64\x65\x64up_state\x18\x06 \x01(\t\x12\x1a\n\x12storage_model_type\x18\x07 \x01(\t\x12\x14\n\x0cstorage_type\x18\x08 \x01(\t\x12\x1a\n\x12storage_type_state\x18\t \x01(\t\x12\x13\n\x0bxcool_state\x18\n \x01(\t\x12\x66\n\x04tags\x18\x0b \x03(\x0b\x32X.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupstorageconfig.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"i\n VaultsBackupResourceGuardProxies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xd8\x02\n\x14VaultsBackupPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65_tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1d\n\x15protected_items_count\x18\x05 \x01(\x05\x12)\n!resource_guard_operation_requests\x18\x06 \x03(\t\x12\x61\n\x04tags\x18\x07 \x03(\x0b\x32S.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupPolicies.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb3\x06\n5VaultsBackupFabricsProtectionContainersProtectedItems\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65_tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1e\n\x16\x62\x61\x63kup_management_type\x18\x05 \x01(\t\x12\x17\n\x0f\x62\x61\x63kup_set_name\x18\x06 \x01(\t\x12\x16\n\x0e\x63ontainer_name\x18\x07 \x01(\t\x12\x13\n\x0b\x63reate_mode\x18\x08 \x01(\t\x12%\n\x1d\x64\x65\x66\x65rred_delete_time_in_u_t_c\x18\t \x01(\t\x12&\n\x1e\x64\x65\x66\x65rred_delete_time_remaining\x18\n \x01(\t\x12\x1a\n\x12is_archive_enabled\x18\x0b \x01(\x08\x12,\n$is_deferred_delete_schedule_upcoming\x18\x0c \x01(\x08\x12\x14\n\x0cis_rehydrate\x18\r \x01(\x08\x12(\n is_scheduled_for_deferred_delete\x18\x0e \x01(\x08\x12\x1b\n\x13last_recovery_point\x18\x0f \x01(\t\x12\x11\n\tpolicy_id\x18\x10 \x01(\t\x12\x13\n\x0bpolicy_name\x18\x11 \x01(\t\x12)\n!resource_guard_operation_requests\x18\x12 \x03(\t\x12\x1a\n\x12source_resource_id\x18\x13 \x01(\t\x12\x15\n\rworkload_type\x18\x14 \x01(\t\x12\x82\x01\n\x04tags\x18\x15 \x03(\x0b\x32t.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupFabricsProtectionContainersProtectedItems.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf2\x04\n\'VaultsBackupFabricsProtectionContainers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65_tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1e\n\x16\x62\x61\x63kup_management_type\x18\x05 \x01(\t\x12\x15\n\rfriendly_name\x18\x06 \x01(\t\x12\x15\n\rhealth_status\x18\x07 \x01(\t\x12\x1f\n\x17protectable_object_type\x18\x08 \x01(\t\x12\x1b\n\x13registration_status\x18\t \x01(\t\x12t\n\x04tags\x18\n \x03(\x0b\x32\x66.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupFabricsProtectionContainers.TagsEntry\x12\xaf\x01\n;vaults_backup_fabrics_protection_containers_protected_items\x18\x0b \x03(\x0b\x32j.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupFabricsProtectionContainersProtectedItems\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb2\x03\n)VaultsBackupFabricsBackupProtectionIntent\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65_tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1e\n\x16\x62\x61\x63kup_management_type\x18\x05 \x01(\t\x12\x0f\n\x07item_id\x18\x06 \x01(\t\x12\x11\n\tpolicy_id\x18\x07 \x01(\t\x12\x18\n\x10protection_state\x18\x08 \x01(\t\x12\x1a\n\x12source_resource_id\x18\t \x01(\t\x12v\n\x04tags\x18\n \x03(\x0b\x32h.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupFabricsBackupProtectionIntent.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb0\x03\n\x1dVaultsBackupEncryptionConfigs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65_tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1f\n\x17\x65ncryption_at_rest_type\x18\x05 \x01(\t\x12\'\n\x1finfrastructure_encryption_state\x18\x06 \x01(\t\x12\x0f\n\x07key_uri\x18\x07 \x01(\t\x12\x1a\n\x12last_update_status\x18\x08 \x01(\t\x12\x17\n\x0fsubscription_id\x18\t \x01(\t\x12j\n\x04tags\x18\n \x03(\x0b\x32\\.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupEncryptionConfigs.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf6\x03\n\x12VaultsBackupconfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x65_tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1f\n\x17\x65nhanced_security_state\x18\x05 \x01(\t\x12-\n%is_soft_delete_feature_state_editable\x18\x06 \x01(\x08\x12)\n!resource_guard_operation_requests\x18\x07 \x03(\t\x12!\n\x19soft_delete_feature_state\x18\x08 \x01(\t\x12\x1a\n\x12storage_model_type\x18\t \x01(\t\x12\x14\n\x0cstorage_type\x18\n \x01(\t\x12\x1a\n\x12storage_type_state\x18\x0b \x01(\t\x12_\n\x04tags\x18\x0c \x03(\x0b\x32Q.oak9.tython.azure.microsoft_recoveryservices_backup.VaultsBackupconfig.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_recoveryservices_backup_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VAULTSPRIVATEENDPOINTCONNECTIONS_TAGSENTRY._options = None
  _VAULTSPRIVATEENDPOINTCONNECTIONS_TAGSENTRY._serialized_options = b'8\001'
  _VAULTSBACKUPSTORAGECONFIG_TAGSENTRY._options = None
  _VAULTSBACKUPSTORAGECONFIG_TAGSENTRY._serialized_options = b'8\001'
  _VAULTSBACKUPPOLICIES_TAGSENTRY._options = None
  _VAULTSBACKUPPOLICIES_TAGSENTRY._serialized_options = b'8\001'
  _VAULTSBACKUPFABRICSPROTECTIONCONTAINERSPROTECTEDITEMS_TAGSENTRY._options = None
  _VAULTSBACKUPFABRICSPROTECTIONCONTAINERSPROTECTEDITEMS_TAGSENTRY._serialized_options = b'8\001'
  _VAULTSBACKUPFABRICSPROTECTIONCONTAINERS_TAGSENTRY._options = None
  _VAULTSBACKUPFABRICSPROTECTIONCONTAINERS_TAGSENTRY._serialized_options = b'8\001'
  _VAULTSBACKUPFABRICSBACKUPPROTECTIONINTENT_TAGSENTRY._options = None
  _VAULTSBACKUPFABRICSBACKUPPROTECTIONINTENT_TAGSENTRY._serialized_options = b'8\001'
  _VAULTSBACKUPENCRYPTIONCONFIGS_TAGSENTRY._options = None
  _VAULTSBACKUPENCRYPTIONCONFIGS_TAGSENTRY._serialized_options = b'8\001'
  _VAULTSBACKUPCONFIG_TAGSENTRY._options = None
  _VAULTSBACKUPCONFIG_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_RECOVERYSERVICES_BACKUP._serialized_start=130
  _MICROSOFT_RECOVERYSERVICES_BACKUP._serialized_end=1184
  _VAULTSPRIVATEENDPOINTCONNECTIONS._serialized_start=1187
  _VAULTSPRIVATEENDPOINTCONNECTIONS._serialized_end=1741
  _VAULTSPRIVATEENDPOINTCONNECTIONS_TAGSENTRY._serialized_start=1698
  _VAULTSPRIVATEENDPOINTCONNECTIONS_TAGSENTRY._serialized_end=1741
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=1743
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=1840
  _PRIVATEENDPOINT._serialized_start=1842
  _PRIVATEENDPOINT._serialized_end=1871
  _VAULTSBACKUPSTORAGECONFIG._serialized_start=1874
  _VAULTSBACKUPSTORAGECONFIG._serialized_end=2309
  _VAULTSBACKUPSTORAGECONFIG_TAGSENTRY._serialized_start=1698
  _VAULTSBACKUPSTORAGECONFIG_TAGSENTRY._serialized_end=1741
  _VAULTSBACKUPRESOURCEGUARDPROXIES._serialized_start=2311
  _VAULTSBACKUPRESOURCEGUARDPROXIES._serialized_end=2416
  _VAULTSBACKUPPOLICIES._serialized_start=2419
  _VAULTSBACKUPPOLICIES._serialized_end=2763
  _VAULTSBACKUPPOLICIES_TAGSENTRY._serialized_start=1698
  _VAULTSBACKUPPOLICIES_TAGSENTRY._serialized_end=1741
  _VAULTSBACKUPFABRICSPROTECTIONCONTAINERSPROTECTEDITEMS._serialized_start=2766
  _VAULTSBACKUPFABRICSPROTECTIONCONTAINERSPROTECTEDITEMS._serialized_end=3585
  _VAULTSBACKUPFABRICSPROTECTIONCONTAINERSPROTECTEDITEMS_TAGSENTRY._serialized_start=1698
  _VAULTSBACKUPFABRICSPROTECTIONCONTAINERSPROTECTEDITEMS_TAGSENTRY._serialized_end=1741
  _VAULTSBACKUPFABRICSPROTECTIONCONTAINERS._serialized_start=3588
  _VAULTSBACKUPFABRICSPROTECTIONCONTAINERS._serialized_end=4214
  _VAULTSBACKUPFABRICSPROTECTIONCONTAINERS_TAGSENTRY._serialized_start=1698
  _VAULTSBACKUPFABRICSPROTECTIONCONTAINERS_TAGSENTRY._serialized_end=1741
  _VAULTSBACKUPFABRICSBACKUPPROTECTIONINTENT._serialized_start=4217
  _VAULTSBACKUPFABRICSBACKUPPROTECTIONINTENT._serialized_end=4651
  _VAULTSBACKUPFABRICSBACKUPPROTECTIONINTENT_TAGSENTRY._serialized_start=1698
  _VAULTSBACKUPFABRICSBACKUPPROTECTIONINTENT_TAGSENTRY._serialized_end=1741
  _VAULTSBACKUPENCRYPTIONCONFIGS._serialized_start=4654
  _VAULTSBACKUPENCRYPTIONCONFIGS._serialized_end=5086
  _VAULTSBACKUPENCRYPTIONCONFIGS_TAGSENTRY._serialized_start=1698
  _VAULTSBACKUPENCRYPTIONCONFIGS_TAGSENTRY._serialized_end=1741
  _VAULTSBACKUPCONFIG._serialized_start=5089
  _VAULTSBACKUPCONFIG._serialized_end=5591
  _VAULTSBACKUPCONFIG_TAGSENTRY._serialized_start=1698
  _VAULTSBACKUPCONFIG_TAGSENTRY._serialized_end=1741
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_rds.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_rds.proto\x12\x13oak9.tython.aws.rds\x1a\x13shared/shared.proto\"y\n\x16\x44\x42\x43lusterDBClusterRole\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"\xb3\x06\n\x03RDS\x12O\n\x1a\x64\x62_cluster_db_cluster_role\x18\x01 \x03(\x0b\x32+.oak9.tython.aws.rds.DBClusterDBClusterRole\x12\\\n db_cluster_scaling_configuration\x18\x02 \x03(\x0b\x32\x32.oak9.tython.aws.rds.DBClusterScalingConfiguration\x12S\n\x1c\x64\x62_instance_db_instance_role\x18\x03 \x03(\x0b\x32-.oak9.tython.aws.rds.DBInstanceDBInstanceRole\x12V\n\x1d\x64\x62_instance_processor_feature\x18\x04 \x03(\x0b\x32/.oak9.tython.aws.rds.DBInstanceProcessorFeature\x12\x44\n\x14\x64\x62_proxy_auth_format\x18\x05 \x03(\x0b\x32&.oak9.tython.aws.rds.DBProxyAuthFormat\x12\x42\n\x13\x64\x62_proxy_tag_format\x18\x06 \x03(\x0b\x32%.oak9.tython.aws.rds.DBProxyTagFormat\x12\x95\x01\n?db_proxy_target_group_connection_pool_configuration_info_format\x18\x07 \x03(\x0b\x32L.oak9.tython.aws.rds.DBProxyTargetGroupConnectionPoolConfigurationInfoFormat\x12N\n\x19\x64\x62_security_group_ingress\x18\x08 \x03(\x0b\x32+.oak9.tython.aws.rds.DBSecurityGroupIngress\x12^\n!option_group_option_configuration\x18\t \x03(\x0b\x32\x33.oak9.tython.aws.rds.OptionGroupOptionConfiguration\"\xba\x01\n\x1d\x44\x42\x43lusterScalingConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nauto_pause\x18\x02 \x01(\x08\x12\x14\n\x0cmax_capacity\x18\x03 \x01(\x05\x12\x14\n\x0cmin_capacity\x18\x04 \x01(\x05\x12 \n\x18seconds_until_auto_pause\x18\x05 \x01(\x05\"{\n\x18\x44\x42InstanceDBInstanceRole\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"r\n\x1a\x44\x42InstanceProcessorFeature\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xaf\x01\n\x11\x44\x42ProxyAuthFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x61uth_scheme\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08iam_auth\x18\x04 \x01(\t\x12\x12\n\nsecret_arn\x18\x05 \x01(\t\x12\x11\n\tuser_name\x18\x06 \x01(\t\"g\n\x10\x44\x42ProxyTagFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x91\x02\n7DBProxyTargetGroupConnectionPoolConfigurationInfoFormat\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17max_connections_percent\x18\x02 \x01(\x05\x12$\n\x1cmax_idle_connections_percent\x18\x03 \x01(\x05\x12!\n\x19\x63onnection_borrow_timeout\x18\x04 \x01(\x05\x12\x1f\n\x17session_pinning_filters\x18\x05 \x03(\t\x12\x12\n\ninit_query\x18\x06 \x01(\t\"\xca\x01\n\x16\x44\x42SecurityGroupIngress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12\x1e\n\x16\x65_c2_security_group_id\x18\x03 \x01(\t\x12 \n\x18\x65_c2_security_group_name\x18\x04 \x01(\t\x12$\n\x1c\x65_c2_security_group_owner_id\x18\x05 \x01(\t\"p\n\x18OptionGroupOptionSetting\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xab\x02\n\x1eOptionGroupOptionConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12%\n\x1d\x64\x62_security_group_memberships\x18\x02 \x03(\t\x12\x13\n\x0boption_name\x18\x03 \x01(\t\x12\x46\n\x0foption_settings\x18\x04 \x03(\x0b\x32-.oak9.tython.aws.rds.OptionGroupOptionSetting\x12\x16\n\x0eoption_version\x18\x05 \x01(\t\x12\x0c\n\x04port\x18\x06 \x01(\x05\x12&\n\x1evpc_security_group_memberships\x18\x07 \x03(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_rds_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DBCLUSTERDBCLUSTERROLE._serialized_start=63
  _DBCLUSTERDBCLUSTERROLE._serialized_end=184
  _RDS._serialized_start=187
  _RDS._serialized_end=1006
  _DBCLUSTERSCALINGCONFIGURATION._serialized_start=1009
  _DBCLUSTERSCALINGCONFIGURATION._serialized_end=1195
  _DBINSTANCEDBINSTANCEROLE._serialized_start=1197
  _DBINSTANCEDBINSTANCEROLE._serialized_end=1320
  _DBINSTANCEPROCESSORFEATURE._serialized_start=1322
  _DBINSTANCEPROCESSORFEATURE._serialized_end=1436
  _DBPROXYAUTHFORMAT._serialized_start=1439
  _DBPROXYAUTHFORMAT._serialized_end=1614
  _DBPROXYTAGFORMAT._serialized_start=1616
  _DBPROXYTAGFORMAT._serialized_end=1719
  _DBPROXYTARGETGROUPCONNECTIONPOOLCONFIGURATIONINFOFORMAT._serialized_start=1722
  _DBPROXYTARGETGROUPCONNECTIONPOOLCONFIGURATIONINFOFORMAT._serialized_end=1995
  _DBSECURITYGROUPINGRESS._serialized_start=1998
  _DBSECURITYGROUPINGRESS._serialized_end=2200
  _OPTIONGROUPOPTIONSETTING._serialized_start=2202
  _OPTIONGROUPOPTIONSETTING._serialized_end=2314
  _OPTIONGROUPOPTIONCONFIGURATION._serialized_start=2317
  _OPTIONGROUPOPTIONCONFIGURATION._serialized_end=2616
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_address.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgcp/gcp_compute_address.proto\x12\x1foak9.tython.gcp.compute_address\x1a\x13shared/shared.proto\"9\n\x17\x43omputeAddressXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xad\x03\n\x0e\x43omputeAddress\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x64\x64ress_type\x18\x02 \x01(\t\x12\x1a\n\x12\x63reation_timestamp\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07network\x18\x07 \x01(\t\x12\x14\n\x0cnetwork_tier\x18\x08 \x01(\t\x12\x15\n\rprefix_length\x18\t \x01(\x01\x12\x0f\n\x07project\x18\n \x01(\t\x12\x0f\n\x07purpose\x18\x0b \x01(\t\x12\x0e\n\x06region\x18\x0c \x01(\t\x12\x11\n\tself_link\x18\r \x01(\t\x12\x12\n\nsubnetwork\x18\x0e \x01(\t\x12\r\n\x05users\x18\x0f \x03(\t\x12J\n\x08timeouts\x18\x10 \x01(\x0b\x32\x38.oak9.tython.gcp.compute_address.ComputeAddressXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_address_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEADDRESSXTIMEOUTS._serialized_start=87
  _COMPUTEADDRESSXTIMEOUTS._serialized_end=144
  _COMPUTEADDRESS._serialized_start=147
  _COMPUTEADDRESS._serialized_end=576
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_compute_virtualmachinescalesets.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;azure/azure_microsoft_compute_virtualmachinescalesets.proto\x12;oak9.tython.azure.microsoft_compute_virtualmachinescalesets\x1a\x13shared/shared.proto\"\xbd\x07\n!VirtualMachineScaleSetsExtensions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\"\n\x1a\x61uto_upgrade_minor_version\x18\x03 \x01(\x08\x12 \n\x18\x65nable_automatic_upgrade\x18\x04 \x01(\x08\x12\x18\n\x10\x66orce_update_tag\x18\x05 \x01(\t\x12\x91\x01\n\x12protected_settings\x18\x06 \x03(\x0b\x32u.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetsExtensions.ProtectedSettingsEntry\x12\xad\x01\n!protected_settings_from_key_vault\x18\x07 \x03(\x0b\x32\x81\x01.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetsExtensions.ProtectedSettingsFromKeyVaultEntry\x12\"\n\x1aprovision_after_extensions\x18\x08 \x03(\t\x12\x11\n\tpublisher\x18\t \x01(\t\x12~\n\x08settings\x18\n \x03(\x0b\x32l.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetsExtensions.SettingsEntry\x12\x19\n\x11suppress_failures\x18\x0b \x01(\x08\x12\x0c\n\x04type\x18\x0c \x01(\t\x12\x1c\n\x14type_handler_version\x18\r \x01(\t\x1a\x38\n\x16ProtectedSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x44\n\"ProtectedSettingsFromKeyVaultEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x19\n\x0bSourceVault\x12\n\n\x02id\x18\x01 \x01(\t\"\"\n\x14NetworkSecurityGroup\x12\n\n\x02id\x18\x01 \x01(\t\"\xf0\x03\n)Microsoft_Compute_VirtualMachineScaleSets\x12x\n\x1avirtual_machine_scale_sets\x18\x01 \x01(\x0b\x32T.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSets\x12\xad\x01\n6virtual_machine_scale_sets_virtual_machines_extensions\x18\x02 \x03(\x0b\x32m.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetsVirtualMachinesExtensions\x12\x98\x01\n+virtual_machine_scale_sets_virtual_machines\x18\x03 \x03(\x0b\x32\x63.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetsVirtualMachines\"\xa9\x06\n1VirtualMachineScaleSetsVirtualMachinesRunCommands\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x17\n\x0f\x61sync_execution\x18\x04 \x01(\x08\x12\x16\n\x0e\x65rror_blob_uri\x18\x05 \x01(\t\x12\x17\n\x0foutput_blob_uri\x18\x06 \x01(\t\x12i\n\nparameters\x18\x07 \x03(\x0b\x32U.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.RunCommandInputParameter\x12s\n\x14protected_parameters\x18\x08 \x03(\x0b\x32U.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.RunCommandInputParameter\x12\x17\n\x0frun_as_password\x18\t \x01(\t\x12\x13\n\x0brun_as_user\x18\n \x01(\t\x12q\n\x06source\x18\x0b \x01(\x0b\x32\x61.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineRunCommandScriptSource\x12\x1a\n\x12timeout_in_seconds\x18\x0c \x01(\x05\x12\x86\x01\n\x04tags\x18\r \x03(\x0b\x32x.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetsVirtualMachinesRunCommands.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"^\n$VirtualMachineRunCommandScriptSource\x12\x12\n\ncommand_id\x18\x01 \x01(\t\x12\x0e\n\x06script\x18\x02 \x01(\t\x12\x12\n\nscript_uri\x18\x03 \x01(\t\"7\n\x18RunCommandInputParameter\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xd0\x08\n0VirtualMachineScaleSetsVirtualMachinesExtensions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\"\n\x1a\x61uto_upgrade_minor_version\x18\x03 \x01(\x08\x12 \n\x18\x65nable_automatic_upgrade\x18\x04 \x01(\x08\x12\x18\n\x10\x66orce_update_tag\x18\x05 \x01(\t\x12w\n\rinstance_view\x18\x06 \x01(\x0b\x32`.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineExtensionInstanceView\x12\xa1\x01\n\x12protected_settings\x18\x07 \x03(\x0b\x32\x84\x01.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetsVirtualMachinesExtensions.ProtectedSettingsEntry\x12\xbc\x01\n!protected_settings_from_key_vault\x18\x08 \x03(\x0b\x32\x90\x01.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetsVirtualMachinesExtensions.ProtectedSettingsFromKeyVaultEntry\x12\x11\n\tpublisher\x18\t \x01(\t\x12\x8d\x01\n\x08settings\x18\n \x03(\x0b\x32{.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetsVirtualMachinesExtensions.SettingsEntry\x12\x19\n\x11suppress_failures\x18\x0b \x01(\x08\x12\x0c\n\x04type\x18\x0c \x01(\t\x12\x1c\n\x14type_handler_version\x18\r \x01(\t\x1a\x38\n\x16ProtectedSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x44\n\"ProtectedSettingsFromKeyVaultEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa8\x02\n#VirtualMachineExtensionInstanceView\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x61\n\x08statuses\x18\x02 \x03(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.InstanceViewStatus\x12\x64\n\x0bsubstatuses\x18\x03 \x03(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.InstanceViewStatus\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x1c\n\x14type_handler_version\x18\x05 \x01(\t\"h\n\x12InstanceViewStatus\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x16\n\x0e\x64isplay_status\x18\x02 \x01(\t\x12\r\n\x05level\x18\x03 \x01(\t\x12\x0f\n\x07message\x18\x04 \x01(\t\x12\x0c\n\x04time\x18\x05 \x01(\t\"\xeb\x0c\n&VirtualMachineScaleSetsVirtualMachines\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12O\n\x04plan\x18\x04 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.Plan\x12t\n\x17\x61\x64\x64itional_capabilities\x18\x05 \x01(\x0b\x32S.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.AdditionalCapabilities\x12\x18\n\x10\x61vailability_set\x18\x06 \x01(\t\x12l\n\x13\x64iagnostics_profile\x18\x07 \x01(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.DiagnosticsProfile\x12\x66\n\x10hardware_profile\x18\x08 \x01(\x0b\x32L.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.HardwareProfile\x12\x14\n\x0clicense_type\x18\t \x01(\t\x12\x64\n\x0fnetwork_profile\x18\n \x01(\x0b\x32K.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.NetworkProfile\x12\x97\x01\n\x1dnetwork_profile_configuration\x18\x0b \x01(\x0b\x32p.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetVMNetworkProfileConfiguration\x12Z\n\nos_profile\x18\x0c \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.OSProfile\x12\x80\x01\n\x11protection_policy\x18\r \x01(\x0b\x32\x65.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetVMProtectionPolicy\x12\x66\n\x10security_profile\x18\x0e \x01(\x0b\x32L.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.SecurityProfile\x12\x64\n\x0fstorage_profile\x18\x0f \x01(\x0b\x32K.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.StorageProfile\x12\x11\n\tuser_data\x18\x10 \x01(\t\x12{\n\x04tags\x18\x11 \x03(\x0b\x32m.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetsVirtualMachines.TagsEntry\x12\xb0\x01\n8virtual_machine_scale_sets_virtual_machines_run_commands\x18\x12 \x03(\x0b\x32n.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetsVirtualMachinesRunCommands\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa7\x02\n\x0eStorageProfile\x12Y\n\ndata_disks\x18\x01 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.DataDisk\x12\x64\n\x0fimage_reference\x18\x02 \x01(\x0b\x32K.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.ImageReference\x12T\n\x07os_disk\x18\x03 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.OSDisk\"\x9e\x05\n\x06OSDisk\x12\x0f\n\x07\x63\x61\x63hing\x18\x01 \x01(\t\x12\x15\n\rcreate_option\x18\x02 \x01(\t\x12\x15\n\rdelete_option\x18\x03 \x01(\t\x12i\n\x12\x64iff_disk_settings\x18\x04 \x01(\x0b\x32M.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.DiffDiskSettings\x12\x14\n\x0c\x64isk_size_gb\x18\x05 \x01(\x05\x12p\n\x13\x65ncryption_settings\x18\x06 \x01(\x0b\x32S.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.DiskEncryptionSettings\x12[\n\x05image\x18\x07 \x01(\x0b\x32L.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualHardDisk\x12h\n\x0cmanaged_disk\x18\x08 \x01(\x0b\x32R.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.ManagedDiskParameters\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0f\n\x07os_type\x18\n \x01(\t\x12Y\n\x03vhd\x18\x0b \x01(\x0b\x32L.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualHardDisk\x12!\n\x19write_accelerator_enabled\x18\x0c \x01(\x08\"\x8b\x02\n\x16\x44iskEncryptionSettings\x12q\n\x13\x64isk_encryption_key\x18\x01 \x01(\x0b\x32T.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.KeyVaultSecretReference\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12m\n\x12key_encryption_key\x18\x03 \x01(\x0b\x32Q.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.KeyVaultKeyReference\"\x87\x01\n\x14KeyVaultKeyReference\x12\x0f\n\x07key_url\x18\x01 \x01(\t\x12^\n\x0csource_vault\x18\x02 \x01(\x0b\x32H.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.SourceVault\"\x8d\x01\n\x17KeyVaultSecretReference\x12\x12\n\nsecret_url\x18\x01 \x01(\t\x12^\n\x0csource_vault\x18\x02 \x01(\x0b\x32H.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.SourceVault\"\xee\x03\n\x08\x44\x61taDisk\x12\x0f\n\x07\x63\x61\x63hing\x18\x01 \x01(\t\x12\x15\n\rcreate_option\x18\x02 \x01(\t\x12\x15\n\rdelete_option\x18\x03 \x01(\t\x12\x15\n\rdetach_option\x18\x04 \x01(\t\x12\x14\n\x0c\x64isk_size_gb\x18\x05 \x01(\x05\x12[\n\x05image\x18\x06 \x01(\x0b\x32L.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualHardDisk\x12\x0b\n\x03lun\x18\x07 \x01(\x05\x12h\n\x0cmanaged_disk\x18\x08 \x01(\x0b\x32R.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.ManagedDiskParameters\x12\x0c\n\x04name\x18\t \x01(\t\x12\x16\n\x0eto_be_detached\x18\n \x01(\x08\x12Y\n\x03vhd\x18\x0b \x01(\x0b\x32L.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualHardDisk\x12!\n\x19write_accelerator_enabled\x18\x0c \x01(\x08\"\xa6\x02\n\x15ManagedDiskParameters\x12u\n\x13\x64isk_encryption_set\x18\x01 \x01(\x0b\x32X.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.DiskEncryptionSetParameters\x12\n\n\x02id\x18\x02 \x01(\t\x12l\n\x10security_profile\x18\x03 \x01(\x0b\x32R.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VMDiskSecurityProfile\x12\x1c\n\x14storage_account_type\x18\x04 \x01(\t\"q\n(VirtualMachineScaleSetVMProtectionPolicy\x12\x1d\n\x15protect_from_scale_in\x18\x01 \x01(\x08\x12&\n\x1eprotect_from_scale_set_actions\x18\x02 \x01(\x08\"\xf3\x03\n\tOSProfile\x12\x16\n\x0e\x61\x64min_password\x18\x01 \x01(\t\x12\x16\n\x0e\x61\x64min_username\x18\x02 \x01(\t\x12\"\n\x1a\x61llow_extension_operations\x18\x03 \x01(\x08\x12\x15\n\rcomputer_name\x18\x04 \x01(\t\x12\x13\n\x0b\x63ustom_data\x18\x05 \x01(\t\x12l\n\x13linux_configuration\x18\x06 \x01(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.LinuxConfiguration\x12&\n\x1erequire_guest_provision_signal\x18\x07 \x01(\x08\x12^\n\x07secrets\x18\x08 \x03(\x0b\x32M.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VaultSecretGroup\x12p\n\x15windows_configuration\x18\t \x01(\x0b\x32Q.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.WindowsConfiguration\"\xc9\x01\n3VirtualMachineScaleSetVMNetworkProfileConfiguration\x12\x91\x01\n network_interface_configurations\x18\x01 \x03(\x0b\x32g.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetNetworkConfiguration\"\xb6\x02\n\x0eNetworkProfile\x12\x1b\n\x13network_api_version\x18\x01 \x01(\t\x12\x92\x01\n network_interface_configurations\x18\x02 \x03(\x0b\x32h.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineNetworkInterfaceConfiguration\x12r\n\x12network_interfaces\x18\x03 \x03(\x0b\x32V.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.NetworkInterfaceReference\"O\n\x19NetworkInterfaceReference\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rdelete_option\x18\x02 \x01(\t\x12\x0f\n\x07primary\x18\x03 \x01(\x08\"\xe0\x04\n+VirtualMachineNetworkInterfaceConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rdelete_option\x18\x02 \x01(\t\x12\x89\x01\n\x0c\x64ns_settings\x18\x03 \x01(\x0b\x32s.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineNetworkInterfaceDnsSettingsConfiguration\x12\x1a\n\x12\x64scp_configuration\x18\x04 \x01(\t\x12%\n\x1d\x65nable_accelerated_networking\x18\x05 \x01(\x08\x12\x13\n\x0b\x65nable_fpga\x18\x06 \x01(\x08\x12\x1c\n\x14\x65nable_ip_forwarding\x18\x07 \x01(\x08\x12\x85\x01\n\x11ip_configurations\x18\x08 \x03(\x0b\x32j.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineNetworkInterfaceIPConfiguration\x12q\n\x16network_security_group\x18\t \x01(\x0b\x32Q.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.NetworkSecurityGroup\x12\x0f\n\x07primary\x18\n \x01(\x08\"\x9a\x03\n-VirtualMachineNetworkInterfaceIPConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x31\n)application_gateway_backend_address_pools\x18\x02 \x03(\t\x12#\n\x1b\x61pplication_security_groups\x18\x03 \x03(\t\x12+\n#load_balancer_backend_address_pools\x18\x04 \x03(\t\x12\x0f\n\x07primary\x18\x05 \x01(\x08\x12\"\n\x1aprivate_ip_address_version\x18\x06 \x01(\t\x12\x90\x01\n\x1fpublic_ip_address_configuration\x18\x07 \x01(\x0b\x32g.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachinePublicIPAddressConfiguration\x12\x0e\n\x06subnet\x18\x08 \x01(\t\"\xa0\x04\n*VirtualMachinePublicIPAddressConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rdelete_option\x18\x02 \x01(\t\x12\x88\x01\n\x0c\x64ns_settings\x18\x03 \x01(\x0b\x32r.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachinePublicIPAddressDnsSettingsConfiguration\x12\x1f\n\x17idle_timeout_in_minutes\x18\x04 \x01(\x05\x12\x61\n\x07ip_tags\x18\x05 \x03(\x0b\x32P.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineIpTag\x12!\n\x19public_ip_address_version\x18\x06 \x01(\t\x12#\n\x1bpublic_ip_allocation_method\x18\x07 \x01(\t\x12\x18\n\x10public_ip_prefix\x18\x08 \x01(\t\x12\\\n\x03sku\x18\t \x01(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.PublicIPAddressSku\"7\n\x13VirtualMachineIpTag\x12\x13\n\x0bip_tag_type\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"R\n5VirtualMachinePublicIPAddressDnsSettingsConfiguration\x12\x19\n\x11\x64omain_name_label\x18\x01 \x01(\t\"M\n6VirtualMachineNetworkInterfaceDnsSettingsConfiguration\x12\x13\n\x0b\x64ns_servers\x18\x01 \x03(\t\"\x8d\x01\n\x0fHardwareProfile\x12\x0f\n\x07vm_size\x18\x01 \x01(\t\x12i\n\x12vm_size_properties\x18\x02 \x01(\x0b\x32M.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VMSizeProperties\"\xde\x0e\n\x17VirtualMachineScaleSets\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12h\n\x11\x65xtended_location\x18\x02 \x01(\x0b\x32M.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.ExtendedLocation\x12m\n\x08identity\x18\x03 \x01(\x0b\x32[.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetIdentity\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12O\n\x04plan\x18\x06 \x01(\x0b\x32\x41.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.Plan\x12t\n\x17\x61\x64\x64itional_capabilities\x18\x07 \x01(\x0b\x32S.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.AdditionalCapabilities\x12u\n\x18\x61utomatic_repairs_policy\x18\x08 \x01(\x0b\x32S.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.AutomaticRepairsPolicy\x12\x35\n-do_not_run_extensions_on_overprovisioned_v_ms\x18\t \x01(\x08\x12\x12\n\nhost_group\x18\n \x01(\t\x12\x1a\n\x12orchestration_mode\x18\x0b \x01(\t\x12\x15\n\roverprovision\x18\x0c \x01(\x08\x12#\n\x1bplatform_fault_domain_count\x18\r \x01(\x05\x12!\n\x19proximity_placement_group\x18\x0e \x01(\t\x12\x63\n\x0fscale_in_policy\x18\x0f \x01(\x0b\x32J.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.ScaleInPolicy\x12\x1e\n\x16single_placement_group\x18\x10 \x01(\x08\x12k\n\x13spot_restore_policy\x18\x11 \x01(\x0b\x32N.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.SpotRestorePolicy\x12\x62\n\x0eupgrade_policy\x18\x12 \x01(\x0b\x32J.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.UpgradePolicy\x12}\n\x17virtual_machine_profile\x18\x13 \x01(\x0b\x32\\.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetVMProfile\x12\x14\n\x0czone_balance\x18\x14 \x01(\x08\x12M\n\x03sku\x18\x15 \x01(\x0b\x32@.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.Sku\x12l\n\x04tags\x18\x16 \x03(\x0b\x32^.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSets.TagsEntry\x12\r\n\x05zones\x18\x17 \x03(\t\x12\x8d\x01\n%virtual_machine_scale_sets_extensions\x18\x18 \x03(\x0b\x32^.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetsExtensions\x12\x98\x01\n+virtual_machine_scale_sets_virtual_machines\x18\x19 \x03(\x0b\x32\x63.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetsVirtualMachines\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"3\n\x03Sku\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04tier\x18\x03 \x01(\t\"\xf5\n\n\x1fVirtualMachineScaleSetVMProfile\x12l\n\x13\x61pplication_profile\x18\x01 \x01(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.ApplicationProfile\x12\x64\n\x0f\x62illing_profile\x18\x02 \x01(\x0b\x32K.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.BillingProfile\x12u\n\x14\x63\x61pacity_reservation\x18\x03 \x01(\x0b\x32W.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.CapacityReservationProfile\x12l\n\x13\x64iagnostics_profile\x18\x04 \x01(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.DiagnosticsProfile\x12\x17\n\x0f\x65viction_policy\x18\x05 \x01(\t\x12~\n\x11\x65xtension_profile\x18\x06 \x01(\x0b\x32\x63.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetExtensionProfile\x12|\n\x10hardware_profile\x18\x07 \x01(\x0b\x32\x62.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetHardwareProfile\x12\x14\n\x0clicense_type\x18\x08 \x01(\t\x12z\n\x0fnetwork_profile\x18\t \x01(\x0b\x32\x61.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetNetworkProfile\x12p\n\nos_profile\x18\n \x01(\x0b\x32\\.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetOSProfile\x12\x10\n\x08priority\x18\x0b \x01(\t\x12u\n\x18scheduled_events_profile\x18\x0c \x01(\x0b\x32S.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.ScheduledEventsProfile\x12\x66\n\x10security_profile\x18\r \x01(\x0b\x32L.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.SecurityProfile\x12z\n\x0fstorage_profile\x18\x0e \x01(\x0b\x32\x61.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetStorageProfile\x12\x11\n\tuser_data\x18\x0f \x01(\t\"\xe9\x02\n$VirtualMachineScaleSetStorageProfile\x12o\n\ndata_disks\x18\x01 \x03(\x0b\x32[.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetDataDisk\x12\x64\n\x0fimage_reference\x18\x02 \x01(\x0b\x32K.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.ImageReference\x12j\n\x07os_disk\x18\x03 \x01(\x0b\x32Y.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetOSDisk\"\xfe\x03\n\x1cVirtualMachineScaleSetOSDisk\x12\x0f\n\x07\x63\x61\x63hing\x18\x01 \x01(\t\x12\x15\n\rcreate_option\x18\x02 \x01(\t\x12i\n\x12\x64iff_disk_settings\x18\x03 \x01(\x0b\x32M.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.DiffDiskSettings\x12\x14\n\x0c\x64isk_size_gb\x18\x04 \x01(\x05\x12[\n\x05image\x18\x05 \x01(\x0b\x32L.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualHardDisk\x12~\n\x0cmanaged_disk\x18\x06 \x01(\x0b\x32h.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetManagedDiskParameters\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07os_type\x18\x08 \x01(\t\x12\x16\n\x0evhd_containers\x18\t \x03(\t\x12!\n\x19write_accelerator_enabled\x18\n \x01(\x08\"\x1e\n\x0fVirtualHardDisk\x12\x0b\n\x03uri\x18\x01 \x01(\t\"5\n\x10\x44iffDiskSettings\x12\x0e\n\x06option\x18\x01 \x01(\t\x12\x11\n\tplacement\x18\x02 \x01(\t\"\xa1\x01\n\x0eImageReference\x12\"\n\x1a\x63ommunity_gallery_image_id\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\r\n\x05offer\x18\x03 \x01(\t\x12\x11\n\tpublisher\x18\x04 \x01(\t\x12\x1f\n\x17shared_gallery_image_id\x18\x05 \x01(\t\x12\x0b\n\x03sku\x18\x06 \x01(\t\x12\x0f\n\x07version\x18\x07 \x01(\t\"\xd8\x02\n\x1eVirtualMachineScaleSetDataDisk\x12\x0f\n\x07\x63\x61\x63hing\x18\x01 \x01(\t\x12\x15\n\rcreate_option\x18\x02 \x01(\t\x12\x1c\n\x14\x64isk_iops_read_write\x18\x03 \x01(\x05\x12\x1c\n\x14\x64isk_mbps_read_write\x18\x04 \x01(\x05\x12\x14\n\x0c\x64isk_size_gb\x18\x05 \x01(\x05\x12\x0b\n\x03lun\x18\x06 \x01(\x05\x12~\n\x0cmanaged_disk\x18\x07 \x01(\x0b\x32h.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetManagedDiskParameters\x12\x0c\n\x04name\x18\x08 \x01(\t\x12!\n\x19write_accelerator_enabled\x18\t \x01(\x08\"\xb0\x02\n+VirtualMachineScaleSetManagedDiskParameters\x12u\n\x13\x64isk_encryption_set\x18\x01 \x01(\x0b\x32X.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.DiskEncryptionSetParameters\x12l\n\x10security_profile\x18\x02 \x01(\x0b\x32R.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VMDiskSecurityProfile\x12\x1c\n\x14storage_account_type\x18\x03 \x01(\t\"\xb0\x01\n\x15VMDiskSecurityProfile\x12u\n\x13\x64isk_encryption_set\x18\x01 \x01(\x0b\x32X.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.DiskEncryptionSetParameters\x12 \n\x18security_encryption_type\x18\x02 \x01(\t\")\n\x1b\x44iskEncryptionSetParameters\x12\n\n\x02id\x18\x01 \x01(\t\"\xa6\x01\n\x0fSecurityProfile\x12\x1a\n\x12\x65ncryption_at_host\x18\x01 \x01(\x08\x12\x15\n\rsecurity_type\x18\x02 \x01(\t\x12`\n\ruefi_settings\x18\x03 \x01(\x0b\x32I.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.UefiSettings\"B\n\x0cUefiSettings\x12\x1b\n\x13secure_boot_enabled\x18\x01 \x01(\x08\x12\x15\n\rv_tpm_enabled\x18\x02 \x01(\x08\"\x9c\x01\n\x16ScheduledEventsProfile\x12\x81\x01\n\x1eterminate_notification_profile\x18\x01 \x01(\x0b\x32Y.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.TerminateNotificationProfile\"J\n\x1cTerminateNotificationProfile\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\x12\x1a\n\x12not_before_timeout\x18\x02 \x01(\t\"\xe8\x03\n\x1fVirtualMachineScaleSetOSProfile\x12\x16\n\x0e\x61\x64min_password\x18\x01 \x01(\t\x12\x16\n\x0e\x61\x64min_username\x18\x02 \x01(\t\x12\"\n\x1a\x61llow_extension_operations\x18\x03 \x01(\x08\x12\x1c\n\x14\x63omputer_name_prefix\x18\x04 \x01(\t\x12\x13\n\x0b\x63ustom_data\x18\x05 \x01(\t\x12l\n\x13linux_configuration\x18\x06 \x01(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.LinuxConfiguration\x12^\n\x07secrets\x18\x07 \x03(\x0b\x32M.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VaultSecretGroup\x12p\n\x15windows_configuration\x18\x08 \x01(\x0b\x32Q.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.WindowsConfiguration\"\xab\x03\n\x14WindowsConfiguration\x12{\n\x1b\x61\x64\x64itional_unattend_content\x18\x01 \x03(\x0b\x32V.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.AdditionalUnattendContent\x12 \n\x18\x65nable_automatic_updates\x18\x02 \x01(\x08\x12\x62\n\x0epatch_settings\x18\x03 \x01(\x0b\x32J.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.PatchSettings\x12\x1b\n\x13provision_v_m_agent\x18\x04 \x01(\x08\x12\x11\n\ttime_zone\x18\x05 \x01(\t\x12`\n\x07win_r_m\x18\x06 \x01(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.WinRMConfiguration\"s\n\x12WinRMConfiguration\x12]\n\tlisteners\x18\x01 \x03(\x0b\x32J.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.WinRMListener\":\n\rWinRMListener\x12\x17\n\x0f\x63\x65rtificate_url\x18\x01 \x01(\t\x12\x10\n\x08protocol\x18\x02 \x01(\t\"X\n\rPatchSettings\x12\x17\n\x0f\x61ssessment_mode\x18\x01 \x01(\t\x12\x1a\n\x12\x65nable_hotpatching\x18\x02 \x01(\x08\x12\x12\n\npatch_mode\x18\x03 \x01(\t\"m\n\x19\x41\x64\x64itionalUnattendContent\x12\x16\n\x0e\x63omponent_name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\tpass_name\x18\x03 \x01(\t\x12\x14\n\x0csetting_name\x18\x04 \x01(\t\"\xdd\x01\n\x10VaultSecretGroup\x12^\n\x0csource_vault\x18\x01 \x01(\x0b\x32H.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.SourceVault\x12i\n\x12vault_certificates\x18\x02 \x03(\x0b\x32M.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VaultCertificate\"F\n\x10VaultCertificate\x12\x19\n\x11\x63\x65rtificate_store\x18\x01 \x01(\t\x12\x17\n\x0f\x63\x65rtificate_url\x18\x02 \x01(\t\"\x9f\x02\n\x12LinuxConfiguration\x12\'\n\x1f\x64isable_password_authentication\x18\x01 \x01(\x08\x12g\n\x0epatch_settings\x18\x02 \x01(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.LinuxPatchSettings\x12\x1b\n\x13provision_v_m_agent\x18\x03 \x01(\x08\x12Z\n\x03ssh\x18\x04 \x01(\x0b\x32M.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.SshConfiguration\"r\n\x10SshConfiguration\x12^\n\x0bpublic_keys\x18\x01 \x03(\x0b\x32I.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.SshPublicKey\".\n\x0cSshPublicKey\x12\x10\n\x08key_data\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"A\n\x12LinuxPatchSettings\x12\x17\n\x0f\x61ssessment_mode\x18\x01 \x01(\t\x12\x12\n\npatch_mode\x18\x02 \x01(\t\"\xbe\x02\n$VirtualMachineScaleSetNetworkProfile\x12\x65\n\x0chealth_probe\x18\x01 \x01(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.ApiEntityReference\x12\x1b\n\x13network_api_version\x18\x02 \x01(\t\x12\x91\x01\n network_interface_configurations\x18\x03 \x03(\x0b\x32g.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetNetworkConfiguration\"\xc5\x04\n*VirtualMachineScaleSetNetworkConfiguration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rdelete_option\x18\x03 \x01(\t\x12\x88\x01\n\x0c\x64ns_settings\x18\x04 \x01(\x0b\x32r.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetNetworkConfigurationDnsSettings\x12%\n\x1d\x65nable_accelerated_networking\x18\x05 \x01(\x08\x12\x13\n\x0b\x65nable_fpga\x18\x06 \x01(\x08\x12\x1c\n\x14\x65nable_ip_forwarding\x18\x07 \x01(\x08\x12}\n\x11ip_configurations\x18\x08 \x03(\x0b\x32\x62.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetIPConfiguration\x12q\n\x16network_security_group\x18\t \x01(\x0b\x32Q.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.NetworkSecurityGroup\x12\x0f\n\x07primary\x18\n \x01(\x08\"\xa0\x04\n%VirtualMachineScaleSetIPConfiguration\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x31\n)application_gateway_backend_address_pools\x18\x03 \x03(\t\x12#\n\x1b\x61pplication_security_groups\x18\x04 \x03(\t\x12+\n#load_balancer_backend_address_pools\x18\x05 \x03(\t\x12\'\n\x1fload_balancer_inbound_nat_pools\x18\x06 \x03(\t\x12\x0f\n\x07primary\x18\x07 \x01(\x08\x12\"\n\x1aprivate_ip_address_version\x18\x08 \x01(\t\x12\x98\x01\n\x1fpublic_ip_address_configuration\x18\t \x01(\x0b\x32o.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetPublicIPAddressConfiguration\x12_\n\x06subnet\x18\n \x01(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.ApiEntityReference\"\x93\x04\n2VirtualMachineScaleSetPublicIPAddressConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\rdelete_option\x18\x02 \x01(\t\x12\x90\x01\n\x0c\x64ns_settings\x18\x03 \x01(\x0b\x32z.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetPublicIPAddressConfigurationDnsSettings\x12\x1f\n\x17idle_timeout_in_minutes\x18\x04 \x01(\x05\x12i\n\x07ip_tags\x18\x05 \x03(\x0b\x32X.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetIpTag\x12!\n\x19public_ip_address_version\x18\x06 \x01(\t\x12\x18\n\x10public_ip_prefix\x18\x07 \x01(\t\x12\\\n\x03sku\x18\x08 \x01(\x0b\x32O.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.PublicIPAddressSku\"0\n\x12PublicIPAddressSku\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04tier\x18\x02 \x01(\t\"?\n\x1bVirtualMachineScaleSetIpTag\x12\x13\n\x0bip_tag_type\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\"Z\n=VirtualMachineScaleSetPublicIPAddressConfigurationDnsSettings\x12\x19\n\x11\x64omain_name_label\x18\x01 \x01(\t\"L\n5VirtualMachineScaleSetNetworkConfigurationDnsSettings\x12\x13\n\x0b\x64ns_servers\x18\x01 \x03(\t\" \n\x12\x41piEntityReference\x12\n\n\x02id\x18\x01 \x01(\t\"\x92\x01\n%VirtualMachineScaleSetHardwareProfile\x12i\n\x12vm_size_properties\x18\x01 \x01(\x0b\x32M.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VMSizeProperties\"E\n\x10VMSizeProperties\x12\x18\n\x10v_cpus_available\x18\x01 \x01(\x05\x12\x17\n\x0fv_cpus_per_core\x18\x02 \x01(\x05\"\xba\x01\n&VirtualMachineScaleSetExtensionProfile\x12p\n\nextensions\x18\x01 \x03(\x0b\x32\\.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetExtension\x12\x1e\n\x16\x65xtensions_time_budget\x18\x02 \x01(\t\"\xe5\x01\n\x1fVirtualMachineScaleSetExtension\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x80\x01\n\nproperties\x18\x02 \x03(\x0b\x32l.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetExtension.PropertiesEntry\x1a\x31\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"|\n\x12\x44iagnosticsProfile\x12\x66\n\x10\x62oot_diagnostics\x18\x01 \x01(\x0b\x32L.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.BootDiagnostics\"7\n\x0f\x42ootDiagnostics\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x13\n\x0bstorage_uri\x18\x02 \x01(\t\"@\n\x1a\x43\x61pacityReservationProfile\x12\"\n\x1a\x63\x61pacity_reservation_group\x18\x01 \x01(\t\"#\n\x0e\x42illingProfile\x12\x11\n\tmax_price\x18\x01 \x01(\x01\"\x85\x01\n\x12\x41pplicationProfile\x12o\n\x14gallery_applications\x18\x01 \x03(\x0b\x32Q.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VMGalleryApplication\"r\n\x14VMGalleryApplication\x12\x1f\n\x17\x63onfiguration_reference\x18\x01 \x01(\t\x12\r\n\x05order\x18\x02 \x01(\x05\x12\x1c\n\x14package_reference_id\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x01(\t\"\x8c\x02\n\rUpgradePolicy\x12z\n\x1b\x61utomatic_os_upgrade_policy\x18\x01 \x01(\x0b\x32U.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.AutomaticOSUpgradePolicy\x12\x0c\n\x04mode\x18\x02 \x01(\t\x12q\n\x16rolling_upgrade_policy\x18\x03 \x01(\x0b\x32Q.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.RollingUpgradePolicy\"\x82\x02\n\x14RollingUpgradePolicy\x12!\n\x19\x65nable_cross_zone_upgrade\x18\x01 \x01(\x08\x12\"\n\x1amax_batch_instance_percent\x18\x02 \x01(\x05\x12&\n\x1emax_unhealthy_instance_percent\x18\x03 \x01(\x05\x12/\n\'max_unhealthy_upgraded_instance_percent\x18\x04 \x01(\x05\x12\"\n\x1apause_time_between_batches\x18\x05 \x01(\t\x12&\n\x1eprioritize_unhealthy_instances\x18\x06 \x01(\x08\"c\n\x18\x41utomaticOSUpgradePolicy\x12\"\n\x1a\x64isable_automatic_rollback\x18\x01 \x01(\x08\x12#\n\x1b\x65nable_automatic_os_upgrade\x18\x02 \x01(\x08\"=\n\x11SpotRestorePolicy\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x17\n\x0frestore_timeout\x18\x02 \x01(\t\"6\n\rScaleInPolicy\x12\x16\n\x0e\x66orce_deletion\x18\x01 \x01(\x08\x12\r\n\x05rules\x18\x02 \x03(\t\"V\n\x16\x41utomaticRepairsPolicy\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x14\n\x0cgrace_period\x18\x02 \x01(\t\x12\x15\n\rrepair_action\x18\x03 \x01(\t\"P\n\x16\x41\x64\x64itionalCapabilities\x12\x1b\n\x13hibernation_enabled\x18\x01 \x01(\x08\x12\x19\n\x11ultra_ssd_enabled\x18\x02 \x01(\x08\"P\n\x04Plan\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07product\x18\x02 \x01(\t\x12\x16\n\x0epromotion_code\x18\x03 \x01(\t\x12\x11\n\tpublisher\x18\x04 \x01(\t\"\x89\x02\n\x1eVirtualMachineScaleSetIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x99\x01\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32w.oak9.tython.azure.microsoft_compute_virtualmachinescalesets.VirtualMachineScaleSetIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x10\x45xtendedLocation\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_compute_virtualmachinescalesets_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VIRTUALMACHINESCALESETSEXTENSIONS_PROTECTEDSETTINGSENTRY._options = None
  _VIRTUALMACHINESCALESETSEXTENSIONS_PROTECTEDSETTINGSENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESCALESETSEXTENSIONS_PROTECTEDSETTINGSFROMKEYVAULTENTRY._options = None
  _VIRTUALMACHINESCALESETSEXTENSIONS_PROTECTEDSETTINGSFROMKEYVAULTENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESCALESETSEXTENSIONS_SETTINGSENTRY._options = None
  _VIRTUALMACHINESCALESETSEXTENSIONS_SETTINGSENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESRUNCOMMANDS_TAGSENTRY._options = None
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESRUNCOMMANDS_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS_PROTECTEDSETTINGSENTRY._options = None
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS_PROTECTEDSETTINGSENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS_PROTECTEDSETTINGSFROMKEYVAULTENTRY._options = None
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS_PROTECTEDSETTINGSFROMKEYVAULTENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS_SETTINGSENTRY._options = None
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS_SETTINGSENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESCALESETSVIRTUALMACHINES_TAGSENTRY._options = None
  _VIRTUALMACHINESCALESETSVIRTUALMACHINES_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESCALESETS_TAGSENTRY._options = None
  _VIRTUALMACHINESCALESETS_TAGSENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESCALESETEXTENSION_PROPERTIESENTRY._options = None
  _VIRTUALMACHINESCALESETEXTENSION_PROPERTIESENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESCALESETIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _VIRTUALMACHINESCALESETIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _VIRTUALMACHINESCALESETSEXTENSIONS._serialized_start=146
  _VIRTUALMACHINESCALESETSEXTENSIONS._serialized_end=1103
  _VIRTUALMACHINESCALESETSEXTENSIONS_PROTECTEDSETTINGSENTRY._serialized_start=928
  _VIRTUALMACHINESCALESETSEXTENSIONS_PROTECTEDSETTINGSENTRY._serialized_end=984
  _VIRTUALMACHINESCALESETSEXTENSIONS_PROTECTEDSETTINGSFROMKEYVAULTENTRY._serialized_start=986
  _VIRTUALMACHINESCALESETSEXTENSIONS_PROTECTEDSETTINGSFROMKEYVAULTENTRY._serialized_end=1054
  _VIRTUALMACHINESCALESETSEXTENSIONS_SETTINGSENTRY._serialized_start=1056
  _VIRTUALMACHINESCALESETSEXTENSIONS_SETTINGSENTRY._serialized_end=1103
  _SOURCEVAULT._serialized_start=1105
  _SOURCEVAULT._serialized_end=1130
  _NETWORKSECURITYGROUP._serialized_start=1132
  _NETWORKSECURITYGROUP._serialized_end=1166
  _MICROSOFT_COMPUTE_VIRTUALMACHINESCALESETS._serialized_start=1169
  _MICROSOFT_COMPUTE_VIRTUALMACHINESCALESETS._serialized_end=1665
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESRUNCOMMANDS._serialized_start=1668
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESRUNCOMMANDS._serialized_end=2477
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESRUNCOMMANDS_TAGSENTRY._serialized_start=2434
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESRUNCOMMANDS_TAGSENTRY._serialized_end=2477
  _VIRTUALMACHINERUNCOMMANDSCRIPTSOURCE._serialized_start=2479
  _VIRTUALMACHINERUNCOMMANDSCRIPTSOURCE._serialized_end=2573
  _RUNCOMMANDINPUTPARAMETER._serialized_start=2575
  _RUNCOMMANDINPUTPARAMETER._serialized_end=2630
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS._serialized_start=2633
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS._serialized_end=3737
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS_PROTECTEDSETTINGSENTRY._serialized_start=928
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS_PROTECTEDSETTINGSENTRY._serialized_end=984
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS_PROTECTEDSETTINGSFROMKEYVAULTENTRY._serialized_start=986
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS_PROTECTEDSETTINGSFROMKEYVAULTENTRY._serialized_end=1054
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS_SETTINGSENTRY._serialized_start=1056
  _VIRTUALMACHINESCALESETSVIRTUALMACHINESEXTENSIONS_SETTINGSENTRY._serialized_end=1103
  _VIRTUALMACHINEEXTENSIONINSTANCEVIEW._serialized_start=3740
  _VIRTUALMACHINEEXTENSIONINSTANCEVIEW._serialized_end=4036
  _INSTANCEVIEWSTATUS._serialized_start=4038
  _INSTANCEVIEWSTATUS._serialized_end=4142
  _VIRTUALMACHINESCALESETSVIRTUALMACHINES._serialized_start=4145
  _VIRTUALMACHINESCALESETSVIRTUALMACHINES._serialized_end=5788
  _VIRTUALMACHINESCALESETSVIRTUALMACHINES_TAGSENTRY._serialized_start=2434
  _VIRTUALMACHINESCALESETSVIRTUALMACHINES_TAGSENTRY._serialized_end=2477
  _STORAGEPROFILE._serialized_start=5791
  _STORAGEPROFILE._serialized_end=6086
  _OSDISK._serialized_start=6089
  _OSDISK._serialized_end=6759
  _DISKENCRYPTIONSETTINGS._serialized_start=6762
  _DISKENCRYPTIONSETTINGS._serialized_end=7029
  _KEYVAULTKEYREFERENCE._serialized_start=7032
  _KEYVAULTKEYREFERENCE._serialized_end=7167
  _KEYVAULTSECRETREFERENCE._serialized_start=7170
  _KEYVAULTSECRETREFERENCE._serialized_end=7311
  _DATADISK._serialized_start=7314
  _DATADISK._serialized_end=7808
  _MANAGEDDISKPARAMETERS._serialized_start=7811
  _MANAGEDDISKPARAMETERS._serialized_end=8105
  _VIRTUALMACHINESCALESETVMPROTECTIONPOLICY._serialized_start=8107
  _VIRTUALMACHINESCALESETVMPROTECTIONPOLICY._serialized_end=8220
  _OSPROFILE._serialized_start=8223
  _OSPROFILE._serialized_end=8722
  _VIRTUALMACHINESCALESETVMNETWORKPROFILECONFIGURATION._serialized_start=8725
  _VIRTUALMACHINESCALESETVMNETWORKPROFILECONFIGURATION._serialized_end=8926
  _NETWORKPROFILE._serialized_start=8929
  _NETWORKPROFILE._serialized_end=9239
  _NETWORKINTERFACEREFERENCE._serialized_start=9241
  _NETWORKINTERFACEREFERENCE._serialized_end=9320
  _VIRTUALMACHINENETWORKINTERFACECONFIGURATION._serialized_start=9323
  _VIRTUALMACHINENETWORKINTERFACECONFIGURATION._serialized_end=9931
  _VIRTUALMACHINENETWORKINTERFACEIPCONFIGURATION._serialized_start=9934
  _VIRTUALMACHINENETWORKINTERFACEIPCONFIGURATION._serialized_end=10344
  _VIRTUALMACHINEPUBLICIPADDRESSCONFIGURATION._serialized_start=10347
  _VIRTUALMACHINEPUBLICIPADDRESSCONFIGURATION._serialized_end=10891
  _VIRTUALMACHINEIPTAG._serialized_start=10893
  _VIRTUALMACHINEIPTAG._serialized_end=10948
  _VIRTUALMACHINEPUBLICIPADDRESSDNSSETTINGSCONFIGURATION._serialized_start=10950
  _VIRTUALMACHINEPUBLICIPADDRESSDNSSETTINGSCONFIGURATION._serialized_end=11032
  _VIRTUALMACHINENETWORKINTERFACEDNSSETTINGSCONFIGURATION._serialized_start=11034
  _VIRTUALMACHINENETWORKINTERFACEDNSSETTINGSCONFIGURATION._serialized_end=11111
  _HARDWAREPROFILE._serialized_start=11114
  _HARDWAREPROFILE._serialized_end=11255
  _VIRTUALMACHINESCALESETS._serialized_start=11258
  _VIRTUALMACHINESCALESETS._serialized_end=13144
  _VIRTUALMACHINESCALESETS_TAGSENTRY._serialized_start=2434
  _VIRTUALMACHINESCALESETS_TAGSENTRY._serialized_end=2477
  _SKU._serialized_start=13146
  _SKU._serialized_end=13197
  _VIRTUALMACHINESCALESETVMPROFILE._serialized_start=13200
  _VIRTUALMACHINESCALESETVMPROFILE._serialized_end=14597
  _VIRTUALMACHINESCALESETSTORAGEPROFILE._serialized_start=14600
  _VIRTUALMACHINESCALESETSTORAGEPROFILE._serialized_end=14961
  _VIRTUALMACHINESCALESETOSDISK._serialized_start=14964
  _VIRTUALMACHINESCALESETOSDISK._serialized_end=15474
  _VIRTUALHARDDISK._serialized_start=15476
  _VIRTUALHARDDISK._serialized_end=15506
  _DIFFDISKSETTINGS._serialized_start=15508
  _DIFFDISKSETTINGS._serialized_end=15561
  _IMAGEREFERENCE._serialized_start=15564
  _IMAGEREFERENCE._serialized_end=15725
  _VIRTUALMACHINESCALESETDATADISK._serialized_start=15728
  _VIRTUALMACHINESCALESETDATADISK._serialized_end=16072
  _VIRTUALMACHINESCALESETMANAGEDDISKPARAMETERS._serialized_start=16075
  _VIRTUALMACHINESCALESETMANAGEDDISKPARAMETERS._serialized_end=16379
  _VMDISKSECURITYPROFILE._serialized_start=16382
  _VMDISKSECURITYPROFILE._serialized_end=16558
  _DISKENCRYPTIONSETPARAMETERS._serialized_start=16560
  _DISKENCRYPTIONSETPARAMETERS._serialized_end=16601
  _SECURITYPROFILE._serialized_start=16604
  _SECURITYPROFILE._serialized_end=16770
  _UEFISETTINGS._serialized_start=16772
  _UEFISETTINGS._serialized_end=16838
  _SCHEDULEDEVENTSPROFILE._serialized_start=16841
  _SCHEDULEDEVENTSPROFILE._serialized_end=16997
  _TERMINATENOTIFICATIONPROFILE._serialized_start=16999
  _TERMINATENOTIFICATIONPROFILE._serialized_end=17073
  _VIRTUALMACHINESCALESETOSPROFILE._serialized_start=17076
  _VIRTUALMACHINESCALESETOSPROFILE._serialized_end=17564
  _WINDOWSCONFIGURATION._serialized_start=17567
  _WINDOWSCONFIGURATION._serialized_end=17994
  _WINRMCONFIGURATION._serialized_start=17996
  _WINRMCONFIGURATION._serialized_end=18111
  _WINRMLISTENER._serialized_start=18113
  _WINRMLISTENER._serialized_end=18171
  _PATCHSETTINGS._serialized_start=18173
  _PATCHSETTINGS._serialized_end=18261
  _ADDITIONALUNATTENDCONTENT._serialized_start=18263
  _ADDITIONALUNATTENDCONTENT._serialized_end=18372
  _VAULTSECRETGROUP._serialized_start=18375
  _VAULTSECRETGROUP._serialized_end=18596
  _VAULTCERTIFICATE._serialized_start=18598
  _VAULTCERTIFICATE._serialized_end=18668
  _LINUXCONFIGURATION._serialized_start=18671
  _LINUXCONFIGURATION._serialized_end=18958
  _SSHCONFIGURATION._serialized_start=18960
  _SSHCONFIGURATION._serialized_end=19074
  _SSHPUBLICKEY._serialized_start=19076
  _SSHPUBLICKEY._serialized_end=19122
  _LINUXPATCHSETTINGS._serialized_start=19124
  _LINUXPATCHSETTINGS._serialized_end=19189
  _VIRTUALMACHINESCALESETNETWORKPROFILE._serialized_start=19192
  _VIRTUALMACHINESCALESETNETWORKPROFILE._serialized_end=19510
  _VIRTUALMACHINESCALESETNETWORKCONFIGURATION._serialized_start=19513
  _VIRTUALMACHINESCALESETNETWORKCONFIGURATION._serialized_end=20094
  _VIRTUALMACHINESCALESETIPCONFIGURATION._serialized_start=20097
  _VIRTUALMACHINESCALESETIPCONFIGURATION._serialized_end=20641
  _VIRTUALMACHINESCALESETPUBLICIPADDRESSCONFIGURATION._serialized_start=20644
  _VIRTUALMACHINESCALESETPUBLICIPADDRESSCONFIGURATION._serialized_end=21175
  _PUBLICIPADDRESSSKU._serialized_start=21177
  _PUBLICIPADDRESSSKU._serialized_end=21225
  _VIRTUALMACHINESCALESETIPTAG._serialized_start=21227
  _VIRTUALMACHINESCALESETIPTAG._serialized_end=21290
  _VIRTUALMACHINESCALESETPUBLICIPADDRESSCONFIGURATIONDNSSETTINGS._serialized_start=21292
  _VIRTUALMACHINESCALESETPUBLICIPADDRESSCONFIGURATIONDNSSETTINGS._serialized_end=21382
  _VIRTUALMACHINESCALESETNETWORKCONFIGURATIONDNSSETTINGS._serialized_start=21384
  _VIRTUALMACHINESCALESETNETWORKCONFIGURATIONDNSSETTINGS._serialized_end=21460
  _APIENTITYREFERENCE._serialized_start=21462
  _APIENTITYREFERENCE._serialized_end=21494
  _VIRTUALMACHINESCALESETHARDWAREPROFILE._serialized_start=21497
  _VIRTUALMACHINESCALESETHARDWAREPROFILE._serialized_end=21643
  _VMSIZEPROPERTIES._serialized_start=21645
  _VMSIZEPROPERTIES._serialized_end=21714
  _VIRTUALMACHINESCALESETEXTENSIONPROFILE._serialized_start=21717
  _VIRTUALMACHINESCALESETEXTENSIONPROFILE._serialized_end=21903
  _VIRTUALMACHINESCALESETEXTENSION._serialized_start=21906
  _VIRTUALMACHINESCALESETEXTENSION._serialized_end=22135
  _VIRTUALMACHINESCALESETEXTENSION_PROPERTIESENTRY._serialized_start=22086
  _VIRTUALMACHINESCALESETEXTENSION_PROPERTIESENTRY._serialized_end=22135
  _DIAGNOSTICSPROFILE._serialized_start=22137
  _DIAGNOSTICSPROFILE._serialized_end=22261
  _BOOTDIAGNOSTICS._serialized_start=22263
  _BOOTDIAGNOSTICS._serialized_end=22318
  _CAPACITYRESERVATIONPROFILE._serialized_start=22320
  _CAPACITYRESERVATIONPROFILE._serialized_end=22384
  _BILLINGPROFILE._serialized_start=22386
  _BILLINGPROFILE._serialized_end=22421
  _APPLICATIONPROFILE._serialized_start=22424
  _APPLICATIONPROFILE._serialized_end=22557
  _VMGALLERYAPPLICATION._serialized_start=22559
  _VMGALLERYAPPLICATION._serialized_end=22673
  _UPGRADEPOLICY._serialized_start=22676
  _UPGRADEPOLICY._serialized_end=22944
  _ROLLINGUPGRADEPOLICY._serialized_start=22947
  _ROLLINGUPGRADEPOLICY._serialized_end=23205
  _AUTOMATICOSUPGRADEPOLICY._serialized_start=23207
  _AUTOMATICOSUPGRADEPOLICY._serialized_end=23306
  _SPOTRESTOREPOLICY._serialized_start=23308
  _SPOTRESTOREPOLICY._serialized_end=23369
  _SCALEINPOLICY._serialized_start=23371
  _SCALEINPOLICY._serialized_end=23425
  _AUTOMATICREPAIRSPOLICY._serialized_start=23427
  _AUTOMATICREPAIRSPOLICY._serialized_end=23513
  _ADDITIONALCAPABILITIES._serialized_start=23515
  _ADDITIONALCAPABILITIES._serialized_end=23595
  _PLAN._serialized_start=23597
  _PLAN._serialized_end=23677
  _VIRTUALMACHINESCALESETIDENTITY._serialized_start=23680
  _VIRTUALMACHINESCALESETIDENTITY._serialized_end=23945
  _VIRTUALMACHINESCALESETIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=23884
  _VIRTUALMACHINESCALESETIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=23945
  _EXTENDEDLOCATION._serialized_start=23947
  _EXTENDEDLOCATION._serialized_end=23993
# @@protoc_insertion_point(module_scope)
